@@ -4,16 +4,11 @@
 # Licence GPL v3
 
 
-if (!isGeneric("mask")) {
-	setGeneric("mask", function(x, mask, ...)
-		standardGeneric("mask"))
-}	
-
 
 setMethod('mask', signature(x='Raster', mask='sf'), 
 function(x, mask, ...) {
 	mask <- .sf2sp(mask)
-	mask(x, mask)
+	mask(x, mask, ...)
 }
 )
 
