@@ -5,10 +5,6 @@
 # version 1, April 2012
 
 
-if (!isGeneric('overlay')) {
-	setGeneric('overlay', function(x, y, ...) 
-		standardGeneric('overlay'))
-}
 
 		
 setMethod('overlay', signature(x='Raster', y='Raster'), 
