@@ -4,15 +4,10 @@
 # Licence GPL v3
 
 
-if (!isGeneric('setMinMax')) {
-	setGeneric('setMinMax', function(x)
-		standardGeneric('setMinMax')) 
-	}	
-
 
 	
 setMethod('setMinMax', signature(x='RasterLayer'), 
-function(x) {
+function(x, ...) {
 	w <- getOption('warn')
 	on.exit(options('warn' = w))
 	options('warn'=-1) 
@@ -49,7 +44,7 @@ function(x) {
 
 
 setMethod('setMinMax', signature(x='RasterBrick'), 
-function(x) {
+function(x, ...) {
 	
 	inMem <- inMemory(x)
 
@@ -86,6 +81,8 @@ function(x) {
 		}
 		x@data@min <- minmax[1,]
 		x@data@max <- minmax[2,]
+		x <- readStop(x)
+
 	}
 #	if (datatype == 'logical') {
 #		x@data@min <- as.logical(x@data@min)
@@ -99,7 +96,7 @@ function(x) {
 
 
 setMethod('setMinMax', signature(x='RasterStack'), 
-	function(x) {
+	function(x, ...) {
 		for (i in 1:nlayers(x)) {
 			x@layers[[i]] <- setMinMax(x@layers[[i]])
 		}
